@@ -2,7 +2,7 @@ from safer.api import api_call_search, api_call_get_usdot, api_call_get_mcmx
 from safer.crawler import parse_html_to_tree
 from safer.html import process_search_result_html, process_company_snapshot
 from safer.results import Company, SearchResultSet
-from safer.exceptions import CompanySnapshotNotFoundException
+from safer.exceptions import CompanySnapshotNotFoundException, SAFERUnreachableException
 
 
 class CompanySnapshot:
@@ -22,6 +22,8 @@ class CompanySnapshot:
 
         # Make request
         r = api_call_search(name)
+        if r.status_code > 499:
+            raise SAFERUnreachableException('The SAFER website is currently unreachable.')
         # Parse HTML result to tree
         tree = parse_html_to_tree(r.text)
         if not tree:
@@ -43,6 +45,8 @@ class CompanySnapshot:
             raise ValueError("parameter 'number' must be an int.")
 
         r = api_call_get_mcmx(mcmx=number)
+        if r.status_code > 499:
+            raise SAFERUnreachableException('The SAFER website is currently unreachable.')
         # Parse HTML result to tree
         tree = parse_html_to_tree(r.text)
         if not tree:
@@ -65,6 +69,8 @@ class CompanySnapshot:
             raise ValueError("parameter 'number' must be an int.")
 
         r = api_call_get_usdot(usdot=number)
+        if r.status_code > 499:
+            raise SAFERUnreachableException('The SAFER website is currently unreachable.')
         # Parse HTML result to tree
         tree = parse_html_to_tree(r.text)
         if not tree:
